@@ -9,7 +9,7 @@ debug = False
 if os.path.exists("./debug"):
     sys.path.insert(0,os.path.abspath("../../"))
     debug = True
-from FastCNN.prx.GongDaProxy import predictPicture,predictSingle,predict,train,predictDirectory
+from FastCNN.prx.GongDaProxy import predictPicture,predictSingle,predictDirectory,train,predictDirectory
 """
 function below
 --------------------------
@@ -43,7 +43,7 @@ def printHelp():
     print("\tpredictPicture [picturepath] [modelpath]")
     print("\tpredictSingle [picturepath] [modeltag(directory in models)]")
     print("\tpredict [dirtag(directory in testset)] [modeltag(directory in models)]")
-    print("\ttrain [modeltag]")
+    print("\ttrain [modeltag,nullable]")
 
 def callPredictPicture():
     modelpath = getArg()
@@ -63,11 +63,8 @@ def callPredictPicture():
 
 def callTrain():
     modeltag = getArg()
-    if modeltag:
-        rtn = train(modeltag)
-        return
-    else:
-        print("modeltag can not be null on train process")
+    
+    rtn = train(modeltag)
     print("call train error")
 
 def predictSingle():
@@ -92,7 +89,7 @@ def callPredict():
     
     if modeltag:
         if dirtag:
-            rtn = predict(dirtag,modeltag)
+            rtn = predictDirectory(dirtag,modeltag)
             print(rtn)
             return
         else:
